#### For usage details, check the [Wiki](https://github.com/ManiacalLabs/BiblioPixel/wiki)!
#### If you still need support, please post on the [Maniacal Labs User Group](https://groups.google.com/d/forum/maniacal-labs-users)

For easy hardware interfacing, check out the BiblioPixel supported [AllPixel](http://maniacallabs.com/AllPixel).

Do you have an animation you would like to share? Submit to our [animation repository](https://github.com/ManiacalLabs/BiblioPixelAnimations) or post it to [our Maniacal Labs User Group](https://groups.google.com/d/forum/maniacal-labs-users).

Overview
====

BiblioPixel is a pure Python 3 library for programming light animations. It provides an easy to use, cross-platform, and completely output agnostic framework that greatly eases designing and programming animations for a wide variety of displays.

In the current form, it is designed specifically for displays comprised of LED strips, but there are no real limits on what the output device can be, due to the output driver model.

See the documentation in the [Wiki](https://github.com/ManiacalLabs/BiblioPixel/wiki) for more detailed information.
